from gbvision.cameras.camera_data import CameraData

LIFECAM_STUDIO = CameraData(648.5256168410046, 0.340394, is_immutable=True, name='LIFECAM_STUDIO')

LIFECAM_3000 = CameraData(697.0395744431028, 0.4228539261329407, is_immutable=True, name='LIFECAM_3000')

UNKNOWN_CAMERA = CameraData(0, 0, is_immutable=True, name='UNKNOWN_CAMERA')
